==> foundry_platform_sdk-0.47.0.tar.gz: foundry_platform_sdk-0.47.0/foundry/v2/third_party_applications/models/_website.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List
from typing import Optional
from typing import cast

import pydantic

from foundry.v2.third_party_applications.models._subdomain import Subdomain
from foundry.v2.third_party_applications.models._version_version import VersionVersion
from foundry.v2.third_party_applications.models._website_dict import WebsiteDict


class Website(pydantic.BaseModel):
    """Website"""

    deployed_version: Optional[VersionVersion] = pydantic.Field(
        alias="deployedVersion", default=None
    )

    """The version of the Website that is currently deployed."""

    subdomains: List[Subdomain]

    """The subdomains from which the Website is currently served."""

    model_config = {"extra": "allow"}

    def to_dict(self) -> WebsiteDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(WebsiteDict, self.model_dump(by_alias=True, exclude_unset=True))

==> foundry_platform_sdk-0.74.0.tar.gz: foundry_platform_sdk-0.74.0/foundry/v2/third_party_applications/models/_website.py <==
#  Copyright 2024 Palantir Technologies, Inc.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.


from __future__ import annotations

from typing import List
from typing import Optional
from typing import cast

import pydantic

from foundry.v2.third_party_applications.models._subdomain import Subdomain
from foundry.v2.third_party_applications.models._version_version import VersionVersion
from foundry.v2.third_party_applications.models._website_dict import WebsiteDict


class Website(pydantic.BaseModel):
    """Website"""

    deployed_version: Optional[VersionVersion] = pydantic.Field(alias=str("deployedVersion"), default=None)  # type: ignore[literal-required]

    """The version of the Website that is currently deployed."""

    subdomains: List[Subdomain]

    """The subdomains from which the Website is currently served."""

    model_config = {"extra": "allow", "populate_by_name": True}

    def to_dict(self) -> WebsiteDict:
        """Return the dictionary representation of the model using the field aliases."""
        return cast(WebsiteDict, self.model_dump(by_alias=True, exclude_unset=True))
